/// <reference types="react" />
import * as React from "react";
import { AuthorKeypair, ClientSettings, IPeer, MultiformatReplica, ReplicaCache, ValidationError } from "earthstar";
declare const ClientSettingsContext: React.Context<ClientSettings>;
/** Subscribe to a given peer's replicas as they change. */
declare function usePeerReplicas(peer: IPeer): import("earthstar").Replica[];
/** Subscribe to an `Earthstar.ClientSetting`'s author.
 *
 * @returns A tuple where the first element is the author, and the second element a function to update the author.
 */
declare function useAuthorSettings(): [
    AuthorKeypair | null,
    (author: AuthorKeypair | null) => void
];
declare function useShareSettings(): [
    string[],
    (shareToAdd: string) => ValidationError | string[],
    (shareToRemove: string) => ValidationError | string[]
];
declare function useShareSecretSettings(): [
    Record<string, string>,
    (share: string, secret: string) => Promise<ValidationError | Record<string, string>>,
    (shareAddrOfSecretToRemove: string) => ValidationError | Record<string, string>
];
declare function useServerSettings(): [
    string[],
    (serverToAdd: string) => ValidationError | string[],
    (serverToRemove: string) => ValidationError | string[]
];
declare function useReplica(replica: MultiformatReplica): ReplicaCache;
declare function AuthorLabel({ address, viewingAuthorSecret, iconSize, ...props }: {
    address: string;
    iconSize?: number;
    viewingAuthorSecret?: string;
} & React.HTMLAttributes<HTMLSpanElement>): JSX.Element;
declare function ShareLabel({ address, viewingAuthorSecret, iconSize, ...props }: {
    address: string;
    iconSize?: number;
    viewingAuthorSecret?: string;
} & React.HTMLAttributes<HTMLSpanElement>): JSX.Element;
export { ClientSettingsContext, usePeerReplicas, useAuthorSettings, useShareSettings, useShareSecretSettings, useServerSettings, useReplica, AuthorLabel, ShareLabel };
